==> deepin-file-manager-debug-1%3A5.8.3-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-file-manager/dde-file-manager-5.8.3/src/dde-file-manager-plugins/pluginPreview/dde-pdf-preview-plugin/qrc_theme.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/deepin-file-manager/src/dde-file-manager-5.8.3/src/dde-file-manager-plugins/pluginPreview/dde-pdf-preview-plugin/dde-pdf-preview.theme
  0x0,0x0,0x0,0xa4,
  0x51,
  0x4c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x23,0x54,0x68,0x75,0x6d,0x62,
  0x6e,0x61,0x69,0x6c,0x7b,0xa,0x20,0x20,0x20,0x20,0x62,0x6f,0x72,0x64,0x65,0x72,
  0x3a,0x20,0x6e,0x6f,0x6e,0x65,0x3b,0xa,0x20,0x20,0x20,0x20,0x62,0x61,0x63,0x6b,
  0x67,0x72,0x6f,0x75,0x6e,0x64,0x3a,0x20,0x77,0x68,0x69,0x74,0x65,0x3b,0xa,0x20,
  0x20,0x20,0x20,0x62,0x6f,0x72,0x64,0x65,0x72,0x2d,0x72,0x69,0x67,0x68,0x74,0x3a,
  0x20,0x31,0x70,0x78,0x20,0x73,0x6f,0x6c,0x69,0x64,0x20,0x72,0x67,0x62,0x61,0x28,
  0x30,0x2c,0x20,0x30,0x2c,0x20,0x30,0x2c,0x20,0x30,0x2e,0x31,0x29,0x3b,0xa,0x7d,
  0x22,0xa,0x51,0x4c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x23,0x54,0x68,
  0x75,0x6d,0x62,0x6e,0x61,0x69,0x6c,0x3a,0x3a,0x69,0x74,0x65,0x6d,0x7b,0xa,0x20,
  0x20,0x20,0x20,0x62,0x6f,0x72,0x64,0x65,0x72,0x3a,0x20,0x6e,0x6f,0x6e,0x65,0x3b,
  0xa,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // light
  0x0,0x5,
  0x0,0x72,0xfd,0xf4,
  0x0,0x6c,
  0x0,0x69,0x0,0x67,0x0,0x68,0x0,0x74,
    // dde-pdf-preview.theme
  0x0,0x15,
  0x8,0x5a,0x87,0xf5,
  0x0,0x64,
  0x0,0x64,0x0,0x65,0x0,0x2d,0x0,0x70,0x0,0x64,0x0,0x66,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,0x65,0x0,0x76,0x0,0x69,0x0,0x65,0x0,0x77,0x0,0x2e,0x0,0x74,
  0x0,0x68,0x0,0x65,0x0,0x6d,0x0,0x65,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x85,0x75,0x69,0x37,0xe0,
  // :/light
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x85,0x75,0x69,0x37,0xe0,
  // :/light/dde-pdf-preview.theme
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x85,0x75,0x69,0x37,0xe0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_theme)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_theme)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_theme)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_theme)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_theme)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_theme)(); }
   } dummy;
}

==> deepin-file-manager-debug-1%3A5.8.3-3-x86_64.pkg.tar.zst: usr/src/debug/deepin-file-manager/dde-file-manager-5.8.3/src/dde-file-manager-plugins/pluginPreview/dde-pdf-preview-plugin/qrc_theme.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.9
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/deepin-file-manager/src/dde-file-manager-5.8.3/src/dde-file-manager-plugins/pluginPreview/dde-pdf-preview-plugin/dde-pdf-preview.theme
  0x0,0x0,0x0,0xa4,
  0x51,
  0x4c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x23,0x54,0x68,0x75,0x6d,0x62,
  0x6e,0x61,0x69,0x6c,0x7b,0xa,0x20,0x20,0x20,0x20,0x62,0x6f,0x72,0x64,0x65,0x72,
  0x3a,0x20,0x6e,0x6f,0x6e,0x65,0x3b,0xa,0x20,0x20,0x20,0x20,0x62,0x61,0x63,0x6b,
  0x67,0x72,0x6f,0x75,0x6e,0x64,0x3a,0x20,0x77,0x68,0x69,0x74,0x65,0x3b,0xa,0x20,
  0x20,0x20,0x20,0x62,0x6f,0x72,0x64,0x65,0x72,0x2d,0x72,0x69,0x67,0x68,0x74,0x3a,
  0x20,0x31,0x70,0x78,0x20,0x73,0x6f,0x6c,0x69,0x64,0x20,0x72,0x67,0x62,0x61,0x28,
  0x30,0x2c,0x20,0x30,0x2c,0x20,0x30,0x2c,0x20,0x30,0x2e,0x31,0x29,0x3b,0xa,0x7d,
  0x22,0xa,0x51,0x4c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x23,0x54,0x68,
  0x75,0x6d,0x62,0x6e,0x61,0x69,0x6c,0x3a,0x3a,0x69,0x74,0x65,0x6d,0x7b,0xa,0x20,
  0x20,0x20,0x20,0x62,0x6f,0x72,0x64,0x65,0x72,0x3a,0x20,0x6e,0x6f,0x6e,0x65,0x3b,
  0xa,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // light
  0x0,0x5,
  0x0,0x72,0xfd,0xf4,
  0x0,0x6c,
  0x0,0x69,0x0,0x67,0x0,0x68,0x0,0x74,
    // dde-pdf-preview.theme
  0x0,0x15,
  0x8,0x5a,0x87,0xf5,
  0x0,0x64,
  0x0,0x64,0x0,0x65,0x0,0x2d,0x0,0x70,0x0,0x64,0x0,0x66,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,0x65,0x0,0x76,0x0,0x69,0x0,0x65,0x0,0x77,0x0,0x2e,0x0,0x74,
  0x0,0x68,0x0,0x65,0x0,0x6d,0x0,0x65,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x87,0x65,0x5,0x68,0x90,
  // :/light
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x87,0x65,0x5,0x68,0x90,
  // :/light/dde-pdf-preview.theme
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x87,0x65,0x5,0x68,0x90,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_theme)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_theme)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_theme)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_theme)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_theme)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_theme)(); }
   } dummy;
}
